.. Copyright 2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Package reahl.web.bootstrap.tabbedpanel
---------------------------------------

.. sidebar:: Examples in this section

   - features.tabbedpanel

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. automodule:: reahl.web.bootstrap.tabbedpanel



TabbedPanel
"""""""""""

.. autoclass:: TabbedPanel
   :members:

Tab
"""

.. autoclass:: Tab
   :members:

MultiTab
""""""""

.. autoclass:: MultiTab
   :members:


